@@ -4,7 +4,7 @@ package Class::C3;
 use strict;
 use warnings;
 
-our $VERSION = '0.19';
+our $VERSION = '0.20';
 
 our $C3_IN_CORE;
 our $C3_XS;
@@ -67,6 +67,11 @@ sub import {
 
 ## initializers
 
+# This prevents silly warnings when Class::C3 is
+#  used explicitly along with MRO::Compat under 5.9.5+
+
+{ no warnings 'redefine';
+
 sub initialize {
     %next::METHOD_CACHE = ();
     # why bother if we don't have anything ...
@@ -100,6 +105,8 @@ sub uninitialize {
 
 sub reinitialize { goto &initialize }
 
+} # end of "no warnings 'redefine'"
+
 ## functions for applying C3 to classes
 
 sub _calculate_method_dispatch_tables {
